==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/WilliamsPercentRIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { WilliamsPercentRIndicatorStrategy } from "./WilliamsPercentRIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var WilliamsPercentRIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WilliamsPercentRIndicator, _super);
    function WilliamsPercentRIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WilliamsPercentRIndicator.prototype.get_yy = function () {
        return new WilliamsPercentRIndicatorStrategy();
    };
    Object.defineProperty(WilliamsPercentRIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    WilliamsPercentRIndicator.prototype.get_zb = function () {
        return WilliamsPercentRIndicator.$;
    };
    Object.defineProperty(WilliamsPercentRIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WilliamsPercentRIndicator.prototype, "zj", {
        get: function () {
            return typeGetValue(this.c(WilliamsPercentRIndicator.zk));
        },
        set: function (a) {
            this.h(WilliamsPercentRIndicator.zk, a);
        },
        enumerable: false,
        configurable: true
    });
    WilliamsPercentRIndicator.prototype.y4 = function () {
        return this.zj;
    };
    WilliamsPercentRIndicator.prototype.zd = function (a) {
        this.zj = a;
    };
    WilliamsPercentRIndicator.$t = markType(WilliamsPercentRIndicator, 'WilliamsPercentRIndicator', StrategyBasedIndicator.$);
    WilliamsPercentRIndicator.zk = StrategyBasedIndicator.zg(14, WilliamsPercentRIndicator.$);
    return WilliamsPercentRIndicator;
}(StrategyBasedIndicator));
export { WilliamsPercentRIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/WilliamsPercentRIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { WilliamsPercentRIndicatorStrategy } from "./WilliamsPercentRIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var WilliamsPercentRIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WilliamsPercentRIndicator, _super);
    function WilliamsPercentRIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WilliamsPercentRIndicator.prototype.bj = function () {
        return new WilliamsPercentRIndicator();
    };
    WilliamsPercentRIndicator.prototype.get_abq = function () {
        return new WilliamsPercentRIndicatorStrategy();
    };
    Object.defineProperty(WilliamsPercentRIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    WilliamsPercentRIndicator.prototype.get_ab3 = function () {
        return WilliamsPercentRIndicator.$;
    };
    Object.defineProperty(WilliamsPercentRIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WilliamsPercentRIndicator.prototype, "acb", {
        get: function () {
            return typeGetValue(this.c(WilliamsPercentRIndicator.acc));
        },
        set: function (a) {
            this.h(WilliamsPercentRIndicator.acc, a);
        },
        enumerable: false,
        configurable: true
    });
    WilliamsPercentRIndicator.prototype.abw = function () {
        return this.acb;
    };
    WilliamsPercentRIndicator.prototype.ab5 = function (a) {
        this.acb = a;
    };
    WilliamsPercentRIndicator.$t = markType(WilliamsPercentRIndicator, 'WilliamsPercentRIndicator', StrategyBasedIndicator.$);
    WilliamsPercentRIndicator.acc = StrategyBasedIndicator.ab8(14, WilliamsPercentRIndicator.$);
    return WilliamsPercentRIndicator;
}(StrategyBasedIndicator));
export { WilliamsPercentRIndicator };
